@@ -1,13 +1,13 @@
 # one axis
 ggplot(as.data.frame(Titanic),
-       aes(weight = Freq,
+       aes(y = Freq,
            axis = Class)) +
   geom_lode(aes(fill = Class, alpha = Survived)) +
-  scale_x_continuous(breaks = 1, labels = c("Class")) +
+  scale_x_discrete(limits = c("Class")) +
   scale_alpha_manual(values = c(.25, .75))
 
 gg <- ggplot(as.data.frame(Titanic),
-             aes(weight = Freq,
+             aes(y = Freq,
                  axis1 = Class, axis2 = Sex, axis3 = Age,
                  fill = Survived))
 # alluvia and lodes
